@@ -4,7 +4,7 @@ Main interface for neptune service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_neptune import (
         Client,
         DBInstanceAvailableWaiter,
@@ -27,10 +27,8 @@ Usage::
         NeptuneClient,
     )
 
-    session = boto3.Session()
-
-    client: NeptuneClient = boto3.client("neptune")
-    session_client: NeptuneClient = session.client("neptune")
+    session = Session()
+    client: NeptuneClient = session.client("neptune")
 
     db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
@@ -52,8 +50,8 @@ Usage::
     describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = client.get_paginator("describe_pending_maintenance_actions")
     ```
 """
-from mypy_boto3_neptune.client import NeptuneClient
-from mypy_boto3_neptune.paginator import (
+from .client import NeptuneClient
+from .paginator import (
     DescribeDBClusterEndpointsPaginator,
     DescribeDBClusterParameterGroupsPaginator,
     DescribeDBClusterParametersPaginator,
@@ -70,7 +68,7 @@ from mypy_boto3_neptune.paginator import (
     DescribeOrderableDBInstanceOptionsPaginator,
     DescribePendingMaintenanceActionsPaginator,
 )
-from mypy_boto3_neptune.waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
+from .waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
 
 Client = NeptuneClient
 
